==> Pyrogram-1.2.20-py3-none-any.whl: pyrogram/raw/functions/payments/get_payment_form.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class GetPaymentForm(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``135``
        - ID: ``0x8a333c8d``

    Parameters:
        peer: :obj:`InputPeer <pyrogram.raw.base.InputPeer>`
        msg_id: ``int`` ``32-bit``
        theme_params (optional): :obj:`DataJSON <pyrogram.raw.base.DataJSON>`

    Returns:
        :obj:`payments.PaymentForm <pyrogram.raw.base.payments.PaymentForm>`
    """

    __slots__: List[str] = ["peer", "msg_id", "theme_params"]

    ID = 0x8a333c8d
    QUALNAME = "functions.payments.GetPaymentForm"

    def __init__(self, *, peer: "raw.base.InputPeer", msg_id: int, theme_params: "raw.base.DataJSON" = None) -> None:
        self.peer = peer  # InputPeer
        self.msg_id = msg_id  # int
        self.theme_params = theme_params  # flags.0?DataJSON

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "GetPaymentForm":
        flags = Int.read(data)
        
        peer = TLObject.read(data)
        
        msg_id = Int.read(data)
        
        theme_params = TLObject.read(data) if flags & (1 << 0) else None
        
        return GetPaymentForm(peer=peer, msg_id=msg_id, theme_params=theme_params)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.theme_params is not None else 0
        data.write(Int(flags))
        
        data.write(self.peer.write())
        
        data.write(Int(self.msg_id))
        
        if self.theme_params is not None:
            data.write(self.theme_params.write())
        
        return data.getvalue()

==> Pyrogram-1.3.0-py3-none-any.whl: pyrogram/raw/functions/payments/get_payment_form.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class GetPaymentForm(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``136``
        - ID: ``0x8a333c8d``

    Parameters:
        peer: :obj:`InputPeer <pyrogram.raw.base.InputPeer>`
        msg_id: ``int`` ``32-bit``
        theme_params (optional): :obj:`DataJSON <pyrogram.raw.base.DataJSON>`

    Returns:
        :obj:`payments.PaymentForm <pyrogram.raw.base.payments.PaymentForm>`
    """

    __slots__: List[str] = ["peer", "msg_id", "theme_params"]

    ID = 0x8a333c8d
    QUALNAME = "functions.payments.GetPaymentForm"

    def __init__(self, *, peer: "raw.base.InputPeer", msg_id: int, theme_params: "raw.base.DataJSON" = None) -> None:
        self.peer = peer  # InputPeer
        self.msg_id = msg_id  # int
        self.theme_params = theme_params  # flags.0?DataJSON

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "GetPaymentForm":
        flags = Int.read(b)
        
        peer = TLObject.read(b)
        
        msg_id = Int.read(b)
        
        theme_params = TLObject.read(b) if flags & (1 << 0) else None
        
        return GetPaymentForm(peer=peer, msg_id=msg_id, theme_params=theme_params)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.theme_params is not None else 0
        b.write(Int(flags))
        
        b.write(self.peer.write())
        
        b.write(Int(self.msg_id))
        
        if self.theme_params is not None:
            b.write(self.theme_params.write())
        
        return b.getvalue()
